<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3474"/>
        <source>Icon size</source>
        <translation>Tamanho do ícone</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3483"/>
        <source>Auto merge</source>
        <translation>Agrupar automaticamente</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3495"/>
        <source>Auto arrange</source>
        <translation>Organizar automaticamente</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3534"/>
        <source>Corner Settings</source>
        <translation>Configurações dos Cantos</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3543"/>
        <location filename="../view/canvasgridview.cpp" line="3548"/>
        <source>Set Wallpaper</source>
        <translation>Definir Papel de Parede</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3546"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Papel de Parede e Protetor de Tela</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3732"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3524"/>
        <source>Display Settings</source>
        <translation>Configurações da Tela</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="23"/>
        <source>Tiny</source>
        <translation>Muito Pequeno</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="24"/>
        <source>Small</source>
        <translation>Pequeno</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="25"/>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="26"/>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="27"/>
        <source>Super large</source>
        <translation>Super Grande</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="158"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="700"/>
        <source>Wallpaper Slideshow</source>
        <translation>Alternar o papel de parede automaticamente</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="746"/>
        <source>When login</source>
        <translation>Quando fizer login</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="748"/>
        <source>When wakeup</source>
        <translation>Quando acordar</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="800"/>
        <source>Require a password on wakeup</source>
        <translation>Solicitar senha ao acordar</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="832"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="834"/>
        <source>Wait:</source>
        <translation>Intervalo:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="867"/>
        <source>Wallpaper</source>
        <translation>Papel de Parede</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="879"/>
        <source>Screensaver</source>
        <translation>Protetor de Tela</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="944"/>
        <source>Loading wallpapers...</source>
        <translation>Carregando os papéis de parede...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="946"/>
        <source>Loading screensavers...</source>
        <translation>Carregando os protetores de tela...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1004"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1005"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Tela de bloqueio</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1006"/>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1094"/>
        <source>Custom Screensaver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1097"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Aplicar</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="127"/>
        <location filename="../view/watermaskframe.cpp" line="128"/>
        <source>Not authorized</source>
        <translation>Não autorizado</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="136"/>
        <location filename="../view/watermaskframe.cpp" line="137"/>
        <source>In trial period</source>
        <translation>Em período de testes</translation>
    </message>
</context>
</TS>